From 7d5110aa6d67a2a8defac2e64e141e4629417381 Mon Sep 17 00:00:00 2001
From: Robert Smith <quad@symbo1ics.com>
Date: Tue, 24 Apr 2012 20:45:05 -0600
Subject: [PATCH 3/3] Add simple numerical predicates POSITIVEP, NEGATIVEP,
 NON-POSITIVE-P, NON-NEGATIVE-P, and NON-ZERO-P.

These functions are more for their clarity and documentation purposes
than their functional purposes. They are seemingly clearer for
especially mathematical code.
---
 numbers.lisp |   23 +++++++++++++++++++++++
 package.lisp |    5 +++++
 2 files changed, 28 insertions(+)

diff --git a/numbers.lisp b/numbers.lisp
index 87a5914..2172897 100644
--- a/numbers.lisp
+++ b/numbers.lisp
@@ -1,5 +1,28 @@
 (in-package :alexandria)
 
+(declaim (inline positivep negativep
+                 non-negative-p non-positive-p
+                 non-zero-p))
+(defun positivep (n)
+  "Decide if N is positive. Alias for PLUSP."
+  (plusp n))
+
+(defun negativep (n)
+  "Decide if N is negative. Alias for MINUSP."
+  (minusp n))
+
+(defun non-negative-p (n)
+  "Decide if N is non-negative."
+  (>= n 0))
+
+(defun non-positive-p (n)
+  "Decide if N is non-positive."
+  (<= n 0))
+
+(defun non-zero-p (n)
+  "Decide if N is non-zero."
+  (not (zerop n)))
+
 (declaim (inline clamp))
 (defun clamp (number min max)
   "Clamps the NUMBER into [min, max] range. Returns MIN if NUMBER is lesser then
diff --git a/package.lisp b/package.lisp
index 9830e98..04f23b2 100644
--- a/package.lisp
+++ b/package.lisp
@@ -96,6 +96,11 @@
    #:median
    #:minf
    #:mulf
+   #:negativep
+   #:non-negative-p
+   #:non-positive-p
+   #:non-zero-p
+   #:positivep
    #:standard-deviation
    #:subfactorial
    #:variance
-- 
1.7.10

